Index: trunk/LMDZ.COMMON/libf/evolution/changelog.txt
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/changelog.txt	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/changelog.txt	(revision 4090)
@@ -886,2 +886,5 @@
 == 18/02/2026 == JBC
 Fallback for 128-bit integers since this type is not supported by Intel Fortran.
+
+== 27/02/2026 == JBC
+Update README and change "startpem.nc" into "startevol.nc".
Index: trunk/LMDZ.COMMON/libf/evolution/clim_state_init.F90
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/clim_state_init.F90	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/clim_state_init.F90	(revision 4090)
@@ -308,5 +308,5 @@
 !
 ! DESCRIPTION
-!     Read the file "startpem.nc" which stores the PEM state.
+!     Read the file "startevol.nc" which stores the PEM state.
 !
 ! AUTHORS & DATE
@@ -367,6 +367,6 @@
 integer(di)                               :: i, islope, k, nb_str_max, nsoil_startpem
 real(dp)                                  :: delta           ! Depth of the interface regolith/breccia, breccia/bedrock [m]
-real(dp), dimension(ngrid,nsoil,nslope)   :: TI_startpem     ! Soil thermal inertia saved in the startpem [SI]
-real(dp), dimension(ngrid,nsoil,nslope)   :: tsoil_startpem  ! Soil temperature saved in the startpem [K]
+real(dp), dimension(ngrid,nsoil,nslope)   :: TI_startpem     ! Soil thermal inertia saved in the startevol [SI]
+real(dp), dimension(ngrid,nsoil,nslope)   :: tsoil_startpem  ! Soil temperature saved in the startevol [K]
 real(dp), dimension(:,:,:,:), allocatable :: layerings_array ! Array for layerings
 
Index: trunk/LMDZ.COMMON/libf/evolution/clim_state_rec.F90
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/clim_state_rec.F90	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/clim_state_rec.F90	(revision 4090)
@@ -25,5 +25,5 @@
 ! VARIABLES
 ! ---------
-logical(k4), private :: is_restartpem = .false. ! Flag to know if "restartpem.nc" exists
+logical(k4), private :: is_restartpem = .false. ! Flag to know if "restartevol.nc" exists
 
 contains
@@ -397,4 +397,5 @@
     call check_nc(nf90_put_att(ncid,varid,'title','Layering ice pore volume fraction'),'putting title attribute for stratif_poreice_volfrac')
 end if
+
 ! Global attributes
 call check_nc(nf90_put_att(ncid,nf90_global,'title','PEM start file'),'putting global attribute')
@@ -421,5 +422,5 @@
 !
 ! DESCRIPTION
-!    Write the file "restartpem.nc".
+!    Write the file "restartevol.nc".
 !
 ! AUTHORS & DATE
Index: trunk/LMDZ.COMMON/libf/evolution/deftank/README
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/deftank/README	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/deftank/README	(revision 4090)
@@ -24,5 +24,5 @@
 Options with example:
     1) [local]     : root name of arch files, assuming that they have been set up for your configuration;
-    2) [planet]    : mars to use the Mars planet physics package;
+    2) [planet]    : mars to use the PEM dedicated to the Mars planet;
     3) [dimensions]: 64x48x54 to define the grid you want to use  (longitude x latitude x atmospheric layers).
 To run the PEM, you need a PCM working with XIOS and consistent options. To compile it, in "LMDZ.COMMON", do: ./makelmdz_fcm -arch [local] -p [planet] -parallel mpi_omp -io xios -d [dimensions] -j 8 gcm
@@ -45,24 +45,24 @@
     > the def files you want to run the PCM: "run.def", "callphys.def", "traceur.def", etc.
       /!\ Do not forget to rename the PCM "run.def" into "run_pcm.def";
-    > the starting files you want to run the PCM: "startfi.nc", "start.nc"/"start1D.txt"/profiles;
+    > the starting files you want to run the PCM: "startfi.nc" and "start.nc"/"start1D.txt";
     > the necessary PEM files: "pem_workflow.sh", "pem_workflow_lib.sh", "pcm_run.job", "pem_run.job", "run_pem.def" and "obl_ecc_lsp.asc";
-    > the optional PEM files: "diagevol.def" to define the PEM variables to be ouputted and "startpem.nc" to set the initial state of the PEM.
+    > the optional PEM files: "diagevol.def" to define the PEM variables to be ouputted and "startevol.nc" to set the initial state of the PEM.
 
 The PEM files can be found in the deftank folder.
 
 Before a simulation, you have to set up some parameters/options in:
-    > "pem_workflow.sh";
-    > "pcm_run.job";
-    > "pem_run.job";
-    > def files, especially for "run_pem.def", "run_pcm.def", "callphys.def".
-In addition, the user has to provide a "startfi.nc" whose orbital parameters are consistent with the initial date set in "run_pem.def". The script "ini_pem_orbit.sh" can do it automatically with "obl_ecc_lsp.asc".
+    > "pem_workflow.sh" (see below for details);
+    > "pcm_run.job" (see below for details);
+    > "pem_run.job" (see below for details);
+    > def files, especially for "run_pem.def", "run_pcm.def" and "callphys.def" which must be consistent. In particular, "run_pem.def" needs to include some definitions for the physics in file "run_pcm.def" with "INCLUDEDEF=run_pcm.def".
+In addition, the user has to provide a "startfi.nc" whose orbital parameters are consistent with the initial date set in "run_pem.def". The script "ini_pem_orbit.sh" can do it automatically reading "obl_ecc_lsp.asc".
 
 Outputs:
 --------
 The PEM simulation generates the following files:
-    > the usual outputs of the PCM: "restartfi.nc", "restart.nc", "diagfi.nc", etc;
+    > the usual outputs of the PCM: "restartfi.nc", "restart.nc"/"restart1D.txt", "diagfi.nc", etc;
     > the XIOS outputs of the PCM: "Xoutdaily4pem*.nc"/"Xoutyearly4pem*.nc";
     > the outputs of the chained simulation: "pem_workflow.log", "pem_workflow.sts" and possibly "kill_pem_workflow.sh";
-    > the usual outputs of the PEM: "restartfi.nc", "restart.nc"/"restart1D.txt" and "diagevol.nc".
+    > the usual outputs of the PEM: "restartevol.nc", "restartfi.nc", "restart.nc"/"restart1D.txt" and "diagevol.nc".
 During the simulation, the PCM/PEM run files are renamed conveniently and stored in the sub-directories "logs" (log files), "starts" (starting files) and "diags" (diagnostic files).
 If you run a simulation by submitting jobs, the script "kill_pem_workflow.sh" is automatically generated. It can be used to kill the jobs related to your chained simulation in the queue of the job scheduler.
@@ -73,8 +73,8 @@
   Bash script file to launch the chained simulation of PEM and PCM runs.
   The user has to specify:
-      > n_mars_years, n_earth_years -> the number of Mars/Earth years to be simulated in total (> 0);
-      > n_pcm_runs_ini -> the number of initial PCM years (>= 2);
-      > n_pcm_runs -> the number of PCM years between each PEM run (>= 2, usually 2);
-      > exec_mode -> the execution mode (0 = "processing scripts"; any other values = "submitting jobs"). The former option is usually used to process the script on a local machine while the latter is used to submit jobs on a supercomputer with SLURM or PBS/TORQUE.
+      > 'n_planetary_years' or 'n_earth_years' -> the number of Planetary/Earth years to be simulated in total (> 0);
+      > 'n_pcm_runs_ini' -> the number of initial PCM years (>= 2);
+      > 'n_pcm_runs' -> the number of PCM years between each PEM run (>= 2, usually 2);
+      > 'exec_mode' -> the execution mode (0 = "processing scripts"; any other values = "submitting jobs"). The former option is usually used to process the script on a local machine while the latter is used to submit jobs on a supercomputer with SLURM or PBS/TORQUE.
   The script can take an argument:
       1) None: to start a simulation from scratch;
@@ -89,6 +89,6 @@
       > The headers correspond to the ADASTRA supercomputer and should be changed for other machines and job schedulers. In case of "processing scripts" execution mode, the headers are naturally omitted.
       > The path to source the arch file should be adapted to the machine.
-      > The name of the PCM executable file should be adapted.
-      > The execution command should also be adapted according to the set-up.
+      > 'pcm_exe', the name of the PCM executable file should be adapted.
+      > 'exec_cmd', the execution command should also be adapted according to the set-up.
 
 # pem_run.job:
@@ -97,10 +97,10 @@
       > The headers correspond to the ADASTRA supercomputer and should be changed for other machines and job schedulers. In case of "processing scripts" execution mode, the headers are naturally omitted.
       > The path to source the arch file should be adapted to the machine.
-      > The name of the PEM executable file should be adapted.
-      > The PEM executable can have an optional argument which should be specified according to the set-up ("--auto-exit" for SLURM and PBS/TORQUE | "" when the script is not run as a job).
+      > 'pem_exe', the name of the PEM executable file should be adapted.
+      > 'pem_arg', the PEM executable can have an optional argument which should be specified according to the set-up ("--auto-exit" for SLURM and PBS/TORQUE | "" when the script is not run as a job).
 
 # run_pem.def
   All the possible parameters to define a PEM run (read in "config.F90").
-  It needs to include in "run_pcm.def" with "INCLUDEDEF=run_pem.def".
+  It needs to include some definitions for the physics in file "run_pcm.def" with "INCLUDEDEF=run_pcm.def".
 
 # obl_ecc_lsp.asc [default], obl_ecc_lsp_pos.asc [future years]
@@ -126,6 +126,6 @@
 
 # visu_layering.py:
-  Python script file to output the stratification data from the "startpem.nc" files.
+  Python script file to output the stratification data from the "startevol.nc" files.
 
 # visu_layering_evol.py:
-  Python script file to output the stratification data over time from the "startpem.nc" files.
+  Python script file to output the stratification data over time from the "startevol.nc" files.
Index: trunk/LMDZ.COMMON/libf/evolution/deftank/clean.sh
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/deftank/clean.sh	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/deftank/clean.sh	(revision 4090)
@@ -35,6 +35,6 @@
     cp starts/start1D.txt .
 fi
-if [ -f "starts/startpem.nc" ]; then
-    cp starts/startpem.nc .
+if [ -f "starts/startevol.nc" ]; then
+    cp starts/startevol.nc .
 fi
 # Cleaning of files in the sub-folders
Index: trunk/LMDZ.COMMON/libf/evolution/deftank/pem_run.job
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/deftank/pem_run.job	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/deftank/pem_run.job	(revision 4090)
@@ -48,6 +48,6 @@
     mv diagevol_soil.nc diags/diagevol_soil${i_pem_run}.nc
 fi
-cp restartpem.nc starts/restartpem${i_pem_run}.nc
-mv restartpem.nc startpem.nc
+cp restartevol.nc starts/restartevol${i_pem_run}.nc
+mv restartevol.nc startevol.nc
 cp restartfi.nc starts/restartfi_postPEM${i_pem_run}.nc
 mv restartfi.nc startfi.nc
Index: trunk/LMDZ.COMMON/libf/evolution/deftank/pem_workflow_lib.sh
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/deftank/pem_workflow_lib.sh	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/deftank/pem_workflow_lib.sh	(revision 4090)
@@ -285,6 +285,6 @@
         cp start1D.txt starts/
     fi
-    if [ -f "startpem.nc" ]; then
-        cp startpem.nc starts/
+    if [ -f "startevol.nc" ]; then
+        cp startevol.nc starts/
     fi
 
@@ -468,8 +468,8 @@
         cleanup starts/restart_postPEM .nc $(($i_pem_run - 1))
         cleanup starts/restartfi_postPEM .nc $(($i_pem_run - 1))
-        cleanup starts/restartpem .nc $(($i_pem_run - 1))
-        rm -f startpem.nc
-        if [ -f "starts/startpem.nc" ]; then
-            cp starts/startpem.nc .
+        cleanup starts/restartevol .nc $(($i_pem_run - 1))
+        rm -f startevol.nc
+        if [ -f "starts/startevol.nc" ]; then
+            cp starts/startevol.nc .
         fi
         if [ $i_resume -eq $(($n_pcm_runs_ini - 1)) ]; then
@@ -498,6 +498,6 @@
         cleanup starts/restart_postPEM .nc $(($i_pem_run - 1))
         cleanup starts/restartfi_postPEM .nc $(($i_pem_run - 1))
-        cleanup starts/restartpem .nc $(($i_pem_run - 1))
-        cp starts/restartpem$(($i_pem_run - 1)).nc startpem.nc
+        cleanup starts/restartevol .nc $(($i_pem_run - 1))
+        cp starts/restartevol$(($i_pem_run - 1)).nc startevol.nc
         if [ $il -eq $(($n_pcm_runs - 1)) ]; then # Second to last PCM run
             cp diags/Xoutdaily4pem${i_resume}.nc Xoutdaily4pem_Y1.nc
@@ -537,6 +537,6 @@
     cleanup starts/restart_postPEM .nc $i_resume
     cleanup starts/restartfi_postPEM .nc $i_resume
-    cleanup starts/restartpem .nc $i_resume
-    cp starts/restartpem${i_resume}.nc startpem.nc
+    cleanup starts/restartevol .nc $i_resume
+    cp starts/restartevol${i_resume}.nc startevol.nc
     cp starts/restartfi_postPEM${i_resume}.nc startfi.nc
     if [ -f "starts/restart_postPEM${i_resume}.nc" ]; then
Index: trunk/LMDZ.COMMON/libf/evolution/deftank/run_pem.def
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/deftank/run_pem.def	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/deftank/run_pem.def	(revision 4090)
@@ -2,7 +2,4 @@
 # Run control parameters for the PEM #
 #------------------------------------#
-
-#---------- Planet type ----------#
-planet_type=mars
 
 #---------- Output parameters ----------#
@@ -77,5 +74,5 @@
 
 #---------- Ice management parameters ----------#
-# Amount of H2O ice to initialize the huge reservoir if the variable is not present in "startpem.nc". Default = 9200. kg.m-2 (= 10 m)
+# Amount of H2O ice to initialize the huge reservoir if the variable is not present in "startevol.nc". Default = 9200. kg.m-2 (= 10 m)
 # h2oice_huge_ini=9200.
 
Index: trunk/LMDZ.COMMON/libf/evolution/deftank/visu_layering.py
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/deftank/visu_layering.py	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/deftank/visu_layering.py	(revision 4090)
@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
 #######################################################################################
-### Python script to output the stratification data from the "restartpem#.nc" files ###
+### Python script to output the stratification data from the "restartevol#.nc" files ###
 #######################################################################################
 
Index: trunk/LMDZ.COMMON/libf/evolution/io_netcdf.F90
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/io_netcdf.F90	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/io_netcdf.F90	(revision 4090)
@@ -32,5 +32,5 @@
 character(11), parameter :: start1D_name   = 'start1D.txt'
 character(10), parameter :: startfi_name   = 'startfi.nc'
-character(11), parameter :: startpem_name  = 'startpem.nc'
+character(12), parameter :: startpem_name  = 'startevol.nc'
 character(19), parameter :: xios_day_name1 = 'Xoutdaily4pem_Y1.nc'  ! XIOS daily output file, second to last PCM year
 character(19), parameter :: xios_day_name2 = 'Xoutdaily4pem_Y2.nc'  ! XIOS daily output file, last PCM year
Index: trunk/LMDZ.COMMON/libf/evolution/pem.F90
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/pem.F90	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/pem.F90	(revision 4090)
@@ -203,5 +203,5 @@
 call compute_maxyr_orbit(n_yr_sim,nmax_yr_runorb)
 
-! Read the "startpem.nc"
+! Read the "startevol.nc"
 allocate(h2o_ice(ngrid,nslope),co2_ice(ngrid,nslope))
 allocate(h2o_ads_reg(ngrid,nsoil,nslope),co2_ads_reg(ngrid,nsoil,nslope),delta_h2o_ads(ngrid),delta_co2_ads(ngrid))
@@ -492,5 +492,5 @@
 call build4PCM_surf_rad_prop(h2o_ice,co2_ice,albedo4PCM,emissivity4PCM)
 
-! Write the "startpem.nc"
+! Write the "startevol.nc"
 call write_restartpem(h2o_ice,co2_ice,tsoil_avg,TI,icetable_depth,icetable_thickness,ice_porefilling,h2o_ads_reg,co2_ads_reg,layerings_map)
 
Index: trunk/LMDZ.COMMON/libf/evolution/soil_temp.F90
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/soil_temp.F90	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/soil_temp.F90	(revision 4090)
@@ -551,5 +551,5 @@
 
 !=======================================================================
-SUBROUTINE evolve_soil_temp(tsoil_avg, tsurf_avg, tsoil_ts, tsoil_ts_old, h2o_soildensity_avg)
+SUBROUTINE evolve_soil_temp(tsoil_avg,tsurf_avg,tsoil_ts,tsoil_ts_old,h2o_soildensity_avg)
 !-----------------------------------------------------------------------
 ! NAME
Index: trunk/LMDZ.COMMON/libf/evolution/xios_data.F90
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/xios_data.F90	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/xios_data.F90	(revision 4090)
@@ -73,4 +73,5 @@
 character(:),                 allocatable    :: num ! To read slope variables
 real(dp), dimension(ngrid,nsoil,nslope,nday) :: h2o_soildensity_ts
+
 ! CODE
 ! ----
@@ -143,4 +144,5 @@
     end if
 end do
+
 ! Close the NetCDF file of XIOS outputs
 call close_nc(xios_yr_name2)

Index: trunk/LMDZ.COMMON/libf/evolution/deftank/visu_layering_evol.py
===================================================================
--- trunk/LMDZ.COMMON/libf/evolution/deftank/visu_layering_evol.py	(revision 4089)
+++ trunk/LMDZ.COMMON/libf/evolution/deftank/visu_layering_evol.py	(revision 4090)
@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
 #######################################################################################################
 ### Python script to output stratification data over time from "restartpem#.nc" files               ###
 ### and to plot orbital parameters from "obl_ecc_lsp.asc"                                           ###
 #######################################################################################################
@@ -21,5 +21,5 @@
     Prompt the user for:
       - folder_path: directory containing NetCDF files (default: "starts")
-      - base_name:   base filename (default: "restartpem")
+      - base_name:   base filename (default: "restartevol")
       - infofile:    name of the PEM info file (default: "pem_workflow.sts")
     Validates existence of folder and infofile before returning.
@@ -37,6 +37,6 @@
     base_name = input(
         "Enter the base name of the NetCDF files "
-        "(press Enter for default [restartpem]): "
-    ).strip() or "restartpem"
+        "(press Enter for default [restartevol]): "
+    ).strip() or "restartevol"
 
     infofile = input(
@@ -1,5 +1,5 @@
 #!/usr/bin/env python3
 #######################################################################################################
-### Python script to output stratification data over time from "restartpem#.nc" files               ###
+### Python script to output stratification data over time from "restartevol#.nc" files               ###
 ### and to plot orbital parameters from "obl_ecc_lsp.asc"                                           ###
 #######################################################################################################